==> 3.1.1.tar.gz: lib/widgets/attention_seekers/head_shake.dart <==
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2020 Sjoerd van den Berg
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

import 'package:flutter/widgets.dart';

import '../../flutter_animator.dart';

///Used by [HeadShake] widget.
///Note: You can also pass this into an [InOutAnimation] widget to define the
///in/out animation.
class HeadShakeAnimation extends AnimationDefinition {
  HeadShakeAnimation({
    AnimationPreferences preferences = const AnimationPreferences(),
  }) : super(preferences: preferences);

  @override
  Widget build(BuildContext context, Animator animator, Widget child) {
    return AnimatedBuilder(
      animation: animator.controller!,
      child: child,
      builder: (BuildContext context, Widget? child) => Transform(
        child: child,
        transform: Matrix4.translationValues(
                animator.get("translateX")!.value, 0.0, 0.0) *
            Matrix4.rotationY(animator.get("rotateY")!.value),
        alignment: Alignment.bottomCenter,
      ),
    );
  }

  @override
  Map<String, TweenList> getDefinition({Size? screenSize, Size? widgetSize}) {
    final curve = Curves.easeInOut;
    return {
      "translateX": TweenList<double>(
        [
          TweenPercentage(percent: 0, value: 0.0, curve: curve),
          TweenPercentage(percent: 13, value: -6.0, curve: curve),
          TweenPercentage(percent: 37, value: 5.0, curve: curve),
          TweenPercentage(percent: 63, value: -3.0, curve: curve),
          TweenPercentage(percent: 87, value: 2.0, curve: curve),
          TweenPercentage(percent: 100, value: 0.0, curve: curve),
        ],
      ),
      "rotateY": TweenList<double>(
        [
          TweenPercentage(percent: 0, value: 0.0, curve: curve),
          TweenPercentage(percent: 13, value: -9.0 * toRad, curve: curve),
          TweenPercentage(percent: 37, value: 7.0 * toRad, curve: curve),
          TweenPercentage(percent: 63, value: -5.0 * toRad, curve: curve),
          TweenPercentage(percent: 87, value: 3.0 * toRad, curve: curve),
          TweenPercentage(percent: 100, value: 0.0, curve: curve),
        ],
      ),
    };
  }
}

/// Example of using HeadShake:
///
/// ```dart
/// class ExampleWidget extends StatelessWidget {
///
///   @override
///   Widget build(BuildContext context) {
///     return HeadShake(child: Text('Bounce'));
///   }
///
/// }
/// ```
class HeadShake extends AnimatorWidget {
  HeadShake({
    Key? key,
    required Widget child,
    AnimationPreferences preferences = const AnimationPreferences(),
  }) : super(
            key: key,
            child: child,
            definition: HeadShakeAnimation(preferences: preferences));
}

==> 3.2.2.tar.gz: lib/widgets/attention_seekers/head_shake.dart <==
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2020 Sjoerd van den Berg
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

import 'package:flutter/widgets.dart';

import '../../flutter_animator.dart';

///Used by [HeadShake] widget.
///Note: You can also pass this into an [InOutAnimation] widget to define the
///in/out animation.
class HeadShakeAnimation extends AnimationDefinition {
  HeadShakeAnimation({
    AnimationPreferences preferences = const AnimationPreferences(),
  }) : super(preferences: preferences);

  @override
  Widget build(BuildContext context, Animator animator, Widget child) {
    return AnimatedBuilder(
      animation: animator.controller!,
      child: child,
      builder: (BuildContext context, Widget? child) => Transform(
        child: child,
        transform: Matrix4.translationValues(
                animator.get("translateX")!.value, 0.0, 0.0) *
            Matrix4.rotationY(animator.get("rotateY")!.value),
        alignment: Alignment.bottomCenter,
      ),
    );
  }

  @override
  Map<String, TweenList> getDefinition({Size? screenSize, Size? widgetSize}) {
    final curve = Curves.easeInOut;
    return {
      "translateX": TweenList<double>(
        [
          TweenPercentage(percent: 0, value: 0.0, curve: curve),
          TweenPercentage(
              percent: 13, value: -6.0 * preferences.magnitude, curve: curve),
          TweenPercentage(
              percent: 37, value: 5.0 * preferences.magnitude, curve: curve),
          TweenPercentage(
              percent: 63, value: -3.0 * preferences.magnitude, curve: curve),
          TweenPercentage(
              percent: 87, value: 2.0 * preferences.magnitude, curve: curve),
          TweenPercentage(percent: 100, value: 0.0, curve: curve),
        ],
      ),
      "rotateY": TweenList<double>(
        [
          TweenPercentage(percent: 0, value: 0.0, curve: curve),
          TweenPercentage(
              percent: 13,
              value: -9.0 * toRad * preferences.magnitude,
              curve: curve),
          TweenPercentage(
              percent: 37,
              value: 7.0 * toRad * preferences.magnitude,
              curve: curve),
          TweenPercentage(
              percent: 63,
              value: -5.0 * toRad * preferences.magnitude,
              curve: curve),
          TweenPercentage(
              percent: 87,
              value: 3.0 * toRad * preferences.magnitude,
              curve: curve),
          TweenPercentage(percent: 100, value: 0.0, curve: curve),
        ],
      ),
    };
  }
}

/// Example of using HeadShake:
///
/// ```dart
/// class ExampleWidget extends StatelessWidget {
///
///   @override
///   Widget build(BuildContext context) {
///     return HeadShake(child: Text('Bounce'));
///   }
///
/// }
/// ```
class HeadShake extends AnimatorWidget {
  HeadShake({
    Key? key,
    required Widget child,
    AnimationPreferences preferences = const AnimationPreferences(),
  }) : super(
            key: key,
            child: child,
            definition: HeadShakeAnimation(preferences: preferences));
}
